@@ -25,40 +25,38 @@ import java.util.Enumeration;
 import java.util.Locale;
 import java.util.Map;
 
-import javax.servlet.AsyncContext;
-import javax.servlet.DispatcherType;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.ServletInputStream;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.Cookie;
-import javax.servlet.http.HttpServletMapping;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
-import javax.servlet.http.HttpUpgradeHandler;
-import javax.servlet.http.Part;
-import javax.servlet.http.PushBuilder;
+import jakarta.servlet.AsyncContext;
+import jakarta.servlet.DispatcherType;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.ServletConnection;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletInputStream;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.Cookie;
+import jakarta.servlet.http.HttpServletMapping;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
+import jakarta.servlet.http.HttpUpgradeHandler;
+import jakarta.servlet.http.Part;
+import jakarta.servlet.http.PushBuilder;
 
 import org.apache.catalina.Globals;
 import org.apache.catalina.security.SecurityUtil;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Facade class that wraps a Coyote request object.
- * All methods are delegated to the wrapped request.
+ * Facade class that wraps a Coyote request object. All methods are delegated to the wrapped request.
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
  */
-@SuppressWarnings("deprecation")
 public class RequestFacade implements HttpServletRequest {
 
 
-    private final class GetAttributePrivilegedAction
-            implements PrivilegedAction<Enumeration<String>> {
+    private final class GetAttributePrivilegedAction implements PrivilegedAction<Enumeration<String>> {
 
         @Override
         public Enumeration<String> run() {
@@ -67,8 +65,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetParameterMapPrivilegedAction
-            implements PrivilegedAction<Map<String,String[]>> {
+    private final class GetParameterMapPrivilegedAction implements PrivilegedAction<Map<String,String[]>> {
 
         @Override
         public Map<String,String[]> run() {
@@ -77,12 +74,11 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetRequestDispatcherPrivilegedAction
-            implements PrivilegedAction<RequestDispatcher> {
+    private final class GetRequestDispatcherPrivilegedAction implements PrivilegedAction<RequestDispatcher> {
 
         private final String path;
 
-        GetRequestDispatcherPrivilegedAction(String path){
+        GetRequestDispatcherPrivilegedAction(String path) {
             this.path = path;
         }
 
@@ -93,12 +89,11 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetParameterPrivilegedAction
-            implements PrivilegedAction<String> {
+    private final class GetParameterPrivilegedAction implements PrivilegedAction<String> {
 
         public String name;
 
-        GetParameterPrivilegedAction(String name){
+        GetParameterPrivilegedAction(String name) {
             this.name = name;
         }
 
@@ -109,8 +104,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetParameterNamesPrivilegedAction
-            implements PrivilegedAction<Enumeration<String>> {
+    private final class GetParameterNamesPrivilegedAction implements PrivilegedAction<Enumeration<String>> {
 
         @Override
         public Enumeration<String> run() {
@@ -119,12 +113,11 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetParameterValuePrivilegedAction
-            implements PrivilegedAction<String[]> {
+    private final class GetParameterValuePrivilegedAction implements PrivilegedAction<String[]> {
 
         public String name;
 
-        GetParameterValuePrivilegedAction(String name){
+        GetParameterValuePrivilegedAction(String name) {
             this.name = name;
         }
 
@@ -135,8 +128,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetCookiesPrivilegedAction
-            implements PrivilegedAction<Cookie[]> {
+    private final class GetCookiesPrivilegedAction implements PrivilegedAction<Cookie[]> {
 
         @Override
         public Cookie[] run() {
@@ -145,8 +137,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetCharacterEncodingPrivilegedAction
-            implements PrivilegedAction<String> {
+    private final class GetCharacterEncodingPrivilegedAction implements PrivilegedAction<String> {
 
         @Override
         public String run() {
@@ -155,12 +146,11 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetHeadersPrivilegedAction
-            implements PrivilegedAction<Enumeration<String>> {
+    private final class GetHeadersPrivilegedAction implements PrivilegedAction<Enumeration<String>> {
 
         private final String name;
 
-        GetHeadersPrivilegedAction(String name){
+        GetHeadersPrivilegedAction(String name) {
             this.name = name;
         }
 
@@ -171,8 +161,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetHeaderNamesPrivilegedAction
-            implements PrivilegedAction<Enumeration<String>> {
+    private final class GetHeaderNamesPrivilegedAction implements PrivilegedAction<Enumeration<String>> {
 
         @Override
         public Enumeration<String> run() {
@@ -181,8 +170,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetLocalePrivilegedAction
-            implements PrivilegedAction<Locale> {
+    private final class GetLocalePrivilegedAction implements PrivilegedAction<Locale> {
 
         @Override
         public Locale run() {
@@ -191,8 +179,7 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetLocalesPrivilegedAction
-            implements PrivilegedAction<Enumeration<Locale>> {
+    private final class GetLocalesPrivilegedAction implements PrivilegedAction<Enumeration<Locale>> {
 
         @Override
         public Enumeration<Locale> run() {
@@ -200,12 +187,11 @@ public class RequestFacade implements HttpServletRequest {
         }
     }
 
-    private final class GetSessionPrivilegedAction
-            implements PrivilegedAction<HttpSession> {
+    private final class GetSessionPrivilegedAction implements PrivilegedAction<HttpSession> {
 
         private final boolean create;
 
-        GetSessionPrivilegedAction(boolean create){
+        GetSessionPrivilegedAction(boolean create) {
             this.create = create;
         }
 
@@ -219,7 +205,6 @@ public class RequestFacade implements HttpServletRequest {
     private static final StringManager sm = StringManager.getManager(RequestFacade.class);
 
 
-
     /**
      * The wrapped request.
      */
@@ -248,8 +233,7 @@ public class RequestFacade implements HttpServletRequest {
      * Prevent cloning the facade.
      */
     @Override
-    protected Object clone()
-        throws CloneNotSupportedException {
+    protected Object clone() throws CloneNotSupportedException {
         throw new CloneNotSupportedException();
     }
 
@@ -267,9 +251,8 @@ public class RequestFacade implements HttpServletRequest {
     public Enumeration<String> getAttributeNames() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetAttributePrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetAttributePrivilegedAction());
         } else {
             return request.getAttributeNames();
         }
@@ -280,9 +263,8 @@ public class RequestFacade implements HttpServletRequest {
     public String getCharacterEncoding() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetCharacterEncodingPrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetCharacterEncodingPrivilegedAction());
         } else {
             return request.getCharacterEncoding();
         }
@@ -321,9 +303,8 @@ public class RequestFacade implements HttpServletRequest {
     public String getParameter(String name) {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetParameterPrivilegedAction(name));
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetParameterPrivilegedAction(name));
         } else {
             return request.getParameter(name);
         }
@@ -334,9 +315,8 @@ public class RequestFacade implements HttpServletRequest {
     public Enumeration<String> getParameterNames() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetParameterNamesPrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetParameterNamesPrivilegedAction());
         } else {
             return request.getParameterNames();
         }
@@ -350,12 +330,11 @@ public class RequestFacade implements HttpServletRequest {
         String[] ret = null;
 
         /*
-         * Clone the returned array only if there is a security manager
-         * in place, so that performance won't suffer in the non-secure case
+         * Clone the returned array only if there is a security manager in place, so that performance won't suffer in
+         * the non-secure case
          */
-        if (SecurityUtil.isPackageProtectionEnabled()){
-            ret = AccessController.doPrivileged(
-                new GetParameterValuePrivilegedAction(name));
+        if (SecurityUtil.isPackageProtectionEnabled()) {
+            ret = AccessController.doPrivileged(new GetParameterValuePrivilegedAction(name));
             if (ret != null) {
                 ret = ret.clone();
             }
@@ -371,9 +350,8 @@ public class RequestFacade implements HttpServletRequest {
     public Map<String,String[]> getParameterMap() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetParameterMapPrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetParameterMapPrivilegedAction());
         } else {
             return request.getParameterMap();
         }
@@ -447,9 +425,8 @@ public class RequestFacade implements HttpServletRequest {
     public Locale getLocale() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetLocalePrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetLocalePrivilegedAction());
         } else {
             return request.getLocale();
         }
@@ -460,9 +437,8 @@ public class RequestFacade implements HttpServletRequest {
     public Enumeration<Locale> getLocales() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetLocalesPrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetLocalesPrivilegedAction());
         } else {
             return request.getLocales();
         }
@@ -480,26 +456,13 @@ public class RequestFacade implements HttpServletRequest {
     public RequestDispatcher getRequestDispatcher(String path) {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetRequestDispatcherPrivilegedAction(path));
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetRequestDispatcherPrivilegedAction(path));
         } else {
             return request.getRequestDispatcher(path);
         }
     }
 
-    @Override
-    public String getRealPath(String path) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
-        return request.getRealPath(path);
-    }
-
-
     @Override
     public String getAuthType() {
         checkFacade();
@@ -514,12 +477,11 @@ public class RequestFacade implements HttpServletRequest {
         Cookie[] ret = null;
 
         /*
-         * Clone the returned array only if there is a security manager
-         * in place, so that performance won't suffer in the non-secure case
+         * Clone the returned array only if there is a security manager in place, so that performance won't suffer in
+         * the non-secure case
          */
-        if (SecurityUtil.isPackageProtectionEnabled()){
-            ret = AccessController.doPrivileged(
-                new GetCookiesPrivilegedAction());
+        if (SecurityUtil.isPackageProtectionEnabled()) {
+            ret = AccessController.doPrivileged(new GetCookiesPrivilegedAction());
             if (ret != null) {
                 ret = ret.clone();
             }
@@ -549,9 +511,8 @@ public class RequestFacade implements HttpServletRequest {
     public Enumeration<String> getHeaders(String name) {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetHeadersPrivilegedAction(name));
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetHeadersPrivilegedAction(name));
         } else {
             return request.getHeaders(name);
         }
@@ -562,9 +523,8 @@ public class RequestFacade implements HttpServletRequest {
     public Enumeration<String> getHeaderNames() {
         checkFacade();
 
-        if (Globals.IS_SECURITY_ENABLED){
-            return AccessController.doPrivileged(
-                new GetHeaderNamesPrivilegedAction());
+        if (Globals.IS_SECURITY_ENABLED) {
+            return AccessController.doPrivileged(new GetHeaderNamesPrivilegedAction());
         } else {
             return request.getHeaderNames();
         }
@@ -673,9 +633,8 @@ public class RequestFacade implements HttpServletRequest {
     public HttpSession getSession(boolean create) {
         checkFacade();
 
-        if (SecurityUtil.isPackageProtectionEnabled()){
-            return AccessController.
-                doPrivileged(new GetSessionPrivilegedAction(create));
+        if (SecurityUtil.isPackageProtectionEnabled()) {
+            return AccessController.doPrivileged(new GetSessionPrivilegedAction(create));
         } else {
             return request.getSession(create);
         }
@@ -714,18 +673,6 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    @Override
-    public boolean isRequestedSessionIdFromUrl() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
-        return request.isRequestedSessionIdFromURL();
-    }
-
-
     @Override
     public String getLocalAddr() {
         checkFacade();
@@ -849,8 +796,8 @@ public class RequestFacade implements HttpServletRequest {
 
 
     @Override
-    public <T extends HttpUpgradeHandler> T upgrade(
-            Class<T> httpUpgradeHandlerClass) throws java.io.IOException, ServletException {
+    public <T extends HttpUpgradeHandler> T upgrade(Class<T> httpUpgradeHandlerClass)
+            throws java.io.IOException, ServletException {
         checkFacade();
         return request.upgrade(httpUpgradeHandlerClass);
     }
@@ -877,12 +824,33 @@ public class RequestFacade implements HttpServletRequest {
 
 
     @Override
-    public Map<String, String> getTrailerFields() {
+    public Map<String,String> getTrailerFields() {
         checkFacade();
         return request.getTrailerFields();
     }
 
 
+    @Override
+    public String getRequestId() {
+        checkFacade();
+        return request.getRequestId();
+    }
+
+
+    @Override
+    public String getProtocolRequestId() {
+        checkFacade();
+        return request.getProtocolRequestId();
+    }
+
+
+    @Override
+    public ServletConnection getServletConnection() {
+        checkFacade();
+        return request.getServletConnection();
+    }
+
+
     private void checkFacade() {
         if (request == null) {
             throw new IllegalStateException(sm.getString("requestFacade.nullRequest"));
