@@ -55,6 +55,8 @@ import org.apache.tomcat.util.res.StringManager;
 /**
  * Minimal implementation of the <b>Manager</b> interface that supports no session persistence or distributable
  * capabilities. This class may be subclassed to create more sophisticated Manager implementations.
+ *
+ * @author Craig R. McClanahan
  */
 public abstract class ManagerBase extends LifecycleMBeanBase implements Manager {
 
@@ -125,12 +127,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      */
     protected Map<String,Session> sessions = new ConcurrentHashMap<>();
 
-    /**
-     * Number of sessions created by this manager.
-     *
-     * @deprecated This will be removed in Tomcat 11
-     */
-    @Deprecated
+    // Number of sessions created by this manager
     protected long sessionCounter = 0;
 
     protected volatile int maxActive = 0;
@@ -147,12 +144,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      */
     protected int rejectedSessions = 0;
 
-    /**
-     * Number of duplicated session ids, anything > 0 means we have problems.
-     *
-     * @deprecated This will be removed in Tomcat 11
-     */
-    @Deprecated
+    // number of duplicated session ids - anything >0 means we have problems
     protected volatile int duplicates = 0;
 
     /**
@@ -197,12 +189,9 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      */
     private boolean persistAuthentication = false;
 
-    /**
-     * Determines if the session notes required by the FORM authentication process are persisted (or replicated for
-     * clusters) by this Manager.
-     */
-    private boolean persistAuthenticationNotes = false;
+    private boolean sessionActivityCheck = Globals.STRICT_SERVLET_COMPLIANCE;
 
+    private boolean sessionLastAccessAtStart = Globals.STRICT_SERVLET_COMPLIANCE;
 
     // ------------------------------------------------------------ Constructors
 
@@ -245,6 +234,30 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
     }
 
 
+    @Override
+    public boolean getSessionActivityCheck() {
+        return sessionActivityCheck;
+    }
+
+
+    @Override
+    public void setSessionActivityCheck(boolean sessionActivityCheck) {
+        this.sessionActivityCheck = sessionActivityCheck;
+    }
+
+
+    @Override
+    public boolean getSessionLastAccessAtStart() {
+        return sessionLastAccessAtStart;
+    }
+
+
+    @Override
+    public void setSessionLastAccessAtStart(boolean sessionLastAccessAtStart) {
+        this.sessionLastAccessAtStart = sessionLastAccessAtStart;
+    }
+
+
     /**
      * Obtain the regular expression used to filter session attribute based on attribute name. The regular expression is
      * anchored so it must match the entire name
@@ -273,7 +286,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      * @throws PatternSyntaxException If the expression is not valid
      */
     public void setSessionAttributeNameFilter(String sessionAttributeNameFilter) throws PatternSyntaxException {
-        if (sessionAttributeNameFilter == null || sessionAttributeNameFilter.isEmpty()) {
+        if (sessionAttributeNameFilter == null || sessionAttributeNameFilter.length() == 0) {
             sessionAttributeNamePattern = null;
         } else {
             sessionAttributeNamePattern = Pattern.compile(sessionAttributeNameFilter);
@@ -331,7 +344,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      */
     public void setSessionAttributeValueClassNameFilter(String sessionAttributeValueClassNameFilter)
             throws PatternSyntaxException {
-        if (sessionAttributeValueClassNameFilter == null || sessionAttributeValueClassNameFilter.isEmpty()) {
+        if (sessionAttributeValueClassNameFilter == null || sessionAttributeValueClassNameFilter.length() == 0) {
             sessionAttributeValueClassNamePattern = null;
         } else {
             sessionAttributeValueClassNamePattern = Pattern.compile(sessionAttributeValueClassNameFilter);
@@ -550,35 +563,6 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
     }
 
 
-    /**
-     * Return whether sessions managed by this manager shall persist authentication notes used by FORM authentication or
-     * not.
-     *
-     * @return {@code true}, sessions managed by this manager shall persist authentication notes used by FORM
-     *             authentication; {@code false} otherwise
-     *
-     * @deprecated Will be removed in Tomcat 10.1.x where it is effectively hard-coded to <code>true</code>
-     */
-    @Deprecated
-    public boolean getPersistAuthenticationNotes() {
-        return this.persistAuthenticationNotes;
-    }
-
-    /**
-     * Set whether sessions managed by this manager shall persist authentication notes used by FORM authentication or
-     * not.
-     *
-     * @param persistAuthenticationNotes if {@code true}, sessions managed by this manager shall persist authentication
-     *                                       notes used by FORM authentication
-     *
-     * @deprecated Will be removed in Tomcat 10.1.x where it is effectively hard-coded to <code>true</code>
-     */
-    @Deprecated
-    public void setPersistAuthenticationNotes(boolean persistAuthenticationNotes) {
-        this.persistAuthenticationNotes = persistAuthenticationNotes;
-    }
-
-
     // --------------------------------------------------------- Public Methods
 
     /**
@@ -600,11 +584,11 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
     public void processExpires() {
 
         long timeNow = System.currentTimeMillis();
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
         int expireHere = 0;
 
-        if (log.isTraceEnabled()) {
-            log.trace("Start expire sessions " + getName() + " at " + timeNow + " sessioncount " + sessions.length);
+        if (log.isDebugEnabled()) {
+            log.debug("Start expire sessions " + getName() + " at " + timeNow + " sessioncount " + sessions.length);
         }
         for (Session session : sessions) {
             if (session != null && !session.isValid()) {
@@ -612,8 +596,8 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
             }
         }
         long timeEnd = System.currentTimeMillis();
-        if (log.isTraceEnabled()) {
-            log.trace("End expire sessions " + getName() + " processingTime " + (timeEnd - timeNow) +
+        if (log.isDebugEnabled()) {
+            log.debug("End expire sessions " + getName() + " processingTime " + (timeEnd - timeNow) +
                     " expired sessions: " + expireHere);
         }
         processingTime += (timeEnd - timeNow);
@@ -636,15 +620,11 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
 
         // Ensure caches for timing stats are the right size by filling with
         // nulls.
-        synchronized (sessionCreationTiming) {
-            while (sessionCreationTiming.size() < TIMING_STATS_CACHE_SIZE) {
-                sessionCreationTiming.add(null);
-            }
+        while (sessionCreationTiming.size() < TIMING_STATS_CACHE_SIZE) {
+            sessionCreationTiming.add(null);
         }
-        synchronized (sessionExpirationTiming) {
-            while (sessionExpirationTiming.size() < TIMING_STATS_CACHE_SIZE) {
-                sessionExpirationTiming.add(null);
-            }
+        while (sessionExpirationTiming.size() < TIMING_STATS_CACHE_SIZE) {
+            sessionExpirationTiming.add(null);
         }
 
         /* Create sessionIdGenerator if not explicitly configured */
@@ -666,12 +646,12 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
             ((Lifecycle) sessionIdGenerator).start();
         } else {
             // Force initialization of the random number generator
-            if (log.isTraceEnabled()) {
-                log.trace("Force random number initialization starting");
+            if (log.isDebugEnabled()) {
+                log.debug("Force random number initialization starting");
             }
             sessionIdGenerator.generateSessionId();
-            if (log.isTraceEnabled()) {
-                log.trace("Force random number initialization completed");
+            if (log.isDebugEnabled()) {
+                log.debug("Force random number initialization completed");
             }
         }
     }
@@ -726,6 +706,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
             id = generateSessionId();
         }
         session.setId(id);
+        sessionCounter++;
 
         SessionTiming timing = new SessionTiming(session.getCreationTime(), 0);
         synchronized (sessionCreationTiming) {
@@ -791,12 +772,6 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
     }
 
 
-    @Override
-    public void changeSessionId(Session session) {
-        rotateSessionId(session);
-    }
-
-
     @Override
     public String rotateSessionId(Session session) {
         String newId = generateSessionId();
@@ -884,7 +859,22 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      * @return a new session id
      */
     protected String generateSessionId() {
-        return sessionIdGenerator.generateSessionId();
+
+        String result = null;
+
+        do {
+            if (result != null) {
+                // Not thread-safe but if one of multiple increments is lost
+                // that is not a big deal since the fact that there was any
+                // duplicate is a much bigger issue.
+                duplicates++;
+            }
+
+            result = sessionIdGenerator.generateSessionId();
+
+        } while (sessions.containsKey(result));
+
+        return result;
     }
 
 
@@ -929,7 +919,7 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
 
     @Override
     public long getSessionCounter() {
-        return getActiveSessions() + getExpiredSessions();
+        return sessionCounter;
     }
 
 
@@ -937,23 +927,12 @@ public abstract class ManagerBase extends LifecycleMBeanBase implements Manager
      * Number of duplicated session IDs generated by the random source. Anything bigger than 0 means problems.
      *
      * @return The count of duplicates
-     *
-     * @deprecated This will be removed in Tomcat 11
      */
-    @Deprecated
     public int getDuplicates() {
         return duplicates;
     }
 
 
-    /**
-     * Set duplicates count.
-     *
-     * @param duplicates the new duplicates count
-     *
-     * @deprecated This will be removed in Tomcat 11
-     */
-    @Deprecated
     public void setDuplicates(int duplicates) {
         this.duplicates = duplicates;
     }
